use microrm::prelude::*;
use test_log::test;

mod common;

// this used to conflict with the microrm metadata table
#[derive(Entity)]
struct Meta {}

#[derive(Database)]
struct MetaConflictDB {
    #[allow(unused)]
    pub meta_list: microrm::IDMap<Meta>,
}

#[test]
fn builtin_name_conflict() {
    let _db: MetaConflictDB = common::open_test_db!();
}

#[derive(Entity)]
struct OrdinaryEntity {
    v: usize,
}

#[derive(Database)]
struct ConflictingDB {
    pub map1: microrm::IDMap<OrdinaryEntity>,
    pub map2: microrm::IDMap<OrdinaryEntity>,
}

#[test]
#[should_panic(expected = "duplicate IDMap for entity ordinary_entity")]
fn multimap_conflict() {
    let db: ConflictingDB = common::open_test_db!();

    assert_eq!(db.map1.count().unwrap(), 0);
    assert_eq!(db.map2.count().unwrap(), 0);

    db.map1.insert(OrdinaryEntity { v: 0 }).unwrap();

    assert_eq!(db.map1.count().unwrap(), 1);
    assert_eq!(db.map2.count().unwrap(), 0);
}
